==> haskell-skylighting-format-context-0.1.0.2-247.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-context.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-context
version:              0.1.0.2
visibility:           public
id:                   skylighting-format-context-0.1.0.2-LTRzJopVqyM1CuHVP6Z3c9
key:                  skylighting-format-context-0.1.0.2-LTRzJopVqyM1CuHVP6Z3c9
license:              BSD-3-Clause
copyright:            © Albert Krewinkel, John MacFarlane
maintainer:           albert@tarleb.com
author:               Albert Krewinkel
homepage:             https://github.com/jgm/skylighting
synopsis:
    ConTeXt formatter for skylighting syntax highlighting
    library

description:
    This module allows tokens produced by skylighting-core
    to be rendered as ConTeXt commands.

category:             Text
abi:                  ae85285cf2eef7f1de8ad65f0d2e89a5
exposed:              True
exposed-modules:      Skylighting.Format.ConTeXt
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/skylighting-format-context-0.1.0.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/skylighting-format-context-0.1.0.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/skylighting-format-context-0.1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-context
hs-libraries:         HSskylighting-format-context-0.1.0.2-LTRzJopVqyM1CuHVP6Z3c9
depends:
    base-4.18.2.1 containers-0.6.7
    skylighting-core-0.14.3-Doguo3BFqgg4PCTJ9olxvN text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-context/html/skylighting-format-context.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-context/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-context-0.1.0.2-248-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-context.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-context
version:              0.1.0.2
visibility:           public
id:                   skylighting-format-context-0.1.0.2-8E1twNGIIaGFbnkFmcHcAL
key:                  skylighting-format-context-0.1.0.2-8E1twNGIIaGFbnkFmcHcAL
license:              BSD-3-Clause
copyright:            © Albert Krewinkel, John MacFarlane
maintainer:           albert@tarleb.com
author:               Albert Krewinkel
homepage:             https://github.com/jgm/skylighting
synopsis:
    ConTeXt formatter for skylighting syntax highlighting
    library

description:
    This module allows tokens produced by skylighting-core
    to be rendered as ConTeXt commands.

category:             Text
abi:                  4f044c4d6424a65dda50babd4eccc42a
exposed:              True
exposed-modules:      Skylighting.Format.ConTeXt
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/skylighting-format-context-0.1.0.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/skylighting-format-context-0.1.0.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/skylighting-format-context-0.1.0.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-context
hs-libraries:         HSskylighting-format-context-0.1.0.2-8E1twNGIIaGFbnkFmcHcAL
depends:
    base-4.18.2.1 containers-0.6.7
    skylighting-core-0.14.3-7mhH9r2pWCw3xU0g23Jkur text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-context/html/skylighting-format-context.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-context/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
